# coding: utf-8

"""
    Deep Lynx

    The construction of megaprojects has consistently demonstrated challenges for project managers in regard to meeting cost, schedule, and performance requirements. Megaproject construction challenges are common place within megaprojects with many active projects in the United States failing to meet cost and schedule efforts by significant margins. Currently, engineering teams operate in siloed tools and disparate teams where connections across design, procurement, and construction systems are translated manually or over brittle point-to-point integrations. The manual nature of data exchange increases the risk of silent errors in the reactor design, with each silent error cascading across the design. These cascading errors lead to uncontrollable risk during construction, resulting in significant delays and cost overruns. Deep Lynx allows for an integrated platform during design and operations of mega projects.  The Deep Lynx Core API delivers a few main features.  1. Provides a set of methods and endpoints for manipulating data in an object oriented database. This allows us to store complex datatypes as records and then to compile them into actual, modifiable objects at run-time. Users can store taxonomies or ontologies in a readable format.  2. Provides methods for storing and retrieving data in a graph database. This data is structured and validated against the aformentioned object oriented database before storage.  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class User(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'identity_provider': 'str',
        'display_name': 'str',
        'email': 'str',
        'admin': 'bool',
        'active': 'bool',
        'reset_required': 'bool',
        'email_valid': 'bool',
        'permissions': 'list[object]',
        'roles': 'list[object]',
        'id': 'str',
        'identity_provider_id': 'str',
        'created_at': 'str',
        'modified_at': 'str',
        'created_by': 'str',
        'modified_by': 'str',
        'reset_token_issued': 'str',
        'keys': 'list[UserKey]'
    }

    attribute_map = {
        'identity_provider': 'identity_provider',
        'display_name': 'display_name',
        'email': 'email',
        'admin': 'admin',
        'active': 'active',
        'reset_required': 'reset_required',
        'email_valid': 'email_valid',
        'permissions': 'permissions',
        'roles': 'roles',
        'id': 'id',
        'identity_provider_id': 'identity_provider_id',
        'created_at': 'created_at',
        'modified_at': 'modified_at',
        'created_by': 'created_by',
        'modified_by': 'modified_by',
        'reset_token_issued': 'reset_token_issued',
        'keys': 'keys'
    }

    def __init__(self, identity_provider=None, display_name=None, email=None, admin=None, active=None, reset_required=None, email_valid=None, permissions=None, roles=None, id=None, identity_provider_id=None, created_at=None, modified_at=None, created_by=None, modified_by=None, reset_token_issued=None, keys=None):  # noqa: E501
        """User - a model defined in Swagger"""  # noqa: E501
        self._identity_provider = None
        self._display_name = None
        self._email = None
        self._admin = None
        self._active = None
        self._reset_required = None
        self._email_valid = None
        self._permissions = None
        self._roles = None
        self._id = None
        self._identity_provider_id = None
        self._created_at = None
        self._modified_at = None
        self._created_by = None
        self._modified_by = None
        self._reset_token_issued = None
        self._keys = None
        self.discriminator = None
        self.identity_provider = identity_provider
        self.display_name = display_name
        self.email = email
        self.admin = admin
        self.active = active
        self.reset_required = reset_required
        self.email_valid = email_valid
        if permissions is not None:
            self.permissions = permissions
        if roles is not None:
            self.roles = roles
        self.id = id
        if identity_provider_id is not None:
            self.identity_provider_id = identity_provider_id
        if created_at is not None:
            self.created_at = created_at
        if modified_at is not None:
            self.modified_at = modified_at
        if created_by is not None:
            self.created_by = created_by
        if modified_by is not None:
            self.modified_by = modified_by
        if reset_token_issued is not None:
            self.reset_token_issued = reset_token_issued
        if keys is not None:
            self.keys = keys

    @property
    def identity_provider(self):
        """Gets the identity_provider of this User.  # noqa: E501


        :return: The identity_provider of this User.  # noqa: E501
        :rtype: str
        """
        return self._identity_provider

    @identity_provider.setter
    def identity_provider(self, identity_provider):
        """Sets the identity_provider of this User.


        :param identity_provider: The identity_provider of this User.  # noqa: E501
        :type: str
        """
        if identity_provider is None:
            raise ValueError("Invalid value for `identity_provider`, must not be `None`")  # noqa: E501

        self._identity_provider = identity_provider

    @property
    def display_name(self):
        """Gets the display_name of this User.  # noqa: E501


        :return: The display_name of this User.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this User.


        :param display_name: The display_name of this User.  # noqa: E501
        :type: str
        """
        if display_name is None:
            raise ValueError("Invalid value for `display_name`, must not be `None`")  # noqa: E501

        self._display_name = display_name

    @property
    def email(self):
        """Gets the email of this User.  # noqa: E501


        :return: The email of this User.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this User.


        :param email: The email of this User.  # noqa: E501
        :type: str
        """
        if email is None:
            raise ValueError("Invalid value for `email`, must not be `None`")  # noqa: E501

        self._email = email

    @property
    def admin(self):
        """Gets the admin of this User.  # noqa: E501


        :return: The admin of this User.  # noqa: E501
        :rtype: bool
        """
        return self._admin

    @admin.setter
    def admin(self, admin):
        """Sets the admin of this User.


        :param admin: The admin of this User.  # noqa: E501
        :type: bool
        """
        if admin is None:
            raise ValueError("Invalid value for `admin`, must not be `None`")  # noqa: E501

        self._admin = admin

    @property
    def active(self):
        """Gets the active of this User.  # noqa: E501


        :return: The active of this User.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this User.


        :param active: The active of this User.  # noqa: E501
        :type: bool
        """
        if active is None:
            raise ValueError("Invalid value for `active`, must not be `None`")  # noqa: E501

        self._active = active

    @property
    def reset_required(self):
        """Gets the reset_required of this User.  # noqa: E501


        :return: The reset_required of this User.  # noqa: E501
        :rtype: bool
        """
        return self._reset_required

    @reset_required.setter
    def reset_required(self, reset_required):
        """Sets the reset_required of this User.


        :param reset_required: The reset_required of this User.  # noqa: E501
        :type: bool
        """
        if reset_required is None:
            raise ValueError("Invalid value for `reset_required`, must not be `None`")  # noqa: E501

        self._reset_required = reset_required

    @property
    def email_valid(self):
        """Gets the email_valid of this User.  # noqa: E501


        :return: The email_valid of this User.  # noqa: E501
        :rtype: bool
        """
        return self._email_valid

    @email_valid.setter
    def email_valid(self, email_valid):
        """Sets the email_valid of this User.


        :param email_valid: The email_valid of this User.  # noqa: E501
        :type: bool
        """
        if email_valid is None:
            raise ValueError("Invalid value for `email_valid`, must not be `None`")  # noqa: E501

        self._email_valid = email_valid

    @property
    def permissions(self):
        """Gets the permissions of this User.  # noqa: E501


        :return: The permissions of this User.  # noqa: E501
        :rtype: list[object]
        """
        return self._permissions

    @permissions.setter
    def permissions(self, permissions):
        """Sets the permissions of this User.


        :param permissions: The permissions of this User.  # noqa: E501
        :type: list[object]
        """

        self._permissions = permissions

    @property
    def roles(self):
        """Gets the roles of this User.  # noqa: E501


        :return: The roles of this User.  # noqa: E501
        :rtype: list[object]
        """
        return self._roles

    @roles.setter
    def roles(self, roles):
        """Sets the roles of this User.


        :param roles: The roles of this User.  # noqa: E501
        :type: list[object]
        """

        self._roles = roles

    @property
    def id(self):
        """Gets the id of this User.  # noqa: E501


        :return: The id of this User.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this User.


        :param id: The id of this User.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def identity_provider_id(self):
        """Gets the identity_provider_id of this User.  # noqa: E501


        :return: The identity_provider_id of this User.  # noqa: E501
        :rtype: str
        """
        return self._identity_provider_id

    @identity_provider_id.setter
    def identity_provider_id(self, identity_provider_id):
        """Sets the identity_provider_id of this User.


        :param identity_provider_id: The identity_provider_id of this User.  # noqa: E501
        :type: str
        """

        self._identity_provider_id = identity_provider_id

    @property
    def created_at(self):
        """Gets the created_at of this User.  # noqa: E501


        :return: The created_at of this User.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this User.


        :param created_at: The created_at of this User.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def modified_at(self):
        """Gets the modified_at of this User.  # noqa: E501


        :return: The modified_at of this User.  # noqa: E501
        :rtype: str
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this User.


        :param modified_at: The modified_at of this User.  # noqa: E501
        :type: str
        """

        self._modified_at = modified_at

    @property
    def created_by(self):
        """Gets the created_by of this User.  # noqa: E501


        :return: The created_by of this User.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this User.


        :param created_by: The created_by of this User.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def modified_by(self):
        """Gets the modified_by of this User.  # noqa: E501


        :return: The modified_by of this User.  # noqa: E501
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """Sets the modified_by of this User.


        :param modified_by: The modified_by of this User.  # noqa: E501
        :type: str
        """

        self._modified_by = modified_by

    @property
    def reset_token_issued(self):
        """Gets the reset_token_issued of this User.  # noqa: E501


        :return: The reset_token_issued of this User.  # noqa: E501
        :rtype: str
        """
        return self._reset_token_issued

    @reset_token_issued.setter
    def reset_token_issued(self, reset_token_issued):
        """Sets the reset_token_issued of this User.


        :param reset_token_issued: The reset_token_issued of this User.  # noqa: E501
        :type: str
        """

        self._reset_token_issued = reset_token_issued

    @property
    def keys(self):
        """Gets the keys of this User.  # noqa: E501


        :return: The keys of this User.  # noqa: E501
        :rtype: list[UserKey]
        """
        return self._keys

    @keys.setter
    def keys(self, keys):
        """Sets the keys of this User.


        :param keys: The keys of this User.  # noqa: E501
        :type: list[UserKey]
        """

        self._keys = keys

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(User, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, User):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa
"""
    Deep Lynx

    The construction of megaprojects has consistently demonstrated challenges for project managers in regard to meeting cost, schedule, and performance requirements. Megaproject construction challenges are common place within megaprojects with many active projects in the United States failing to meet cost and schedule efforts by significant margins. Currently, engineering teams operate in siloed tools and disparate teams where connections across design, procurement, and construction systems are translated manually or over brittle point-to-point integrations. The manual nature of data exchange increases the risk of silent errors in the reactor design, with each silent error cascading across the design. These cascading errors lead to uncontrollable risk during construction, resulting in significant delays and cost overruns. Deep Lynx allows for an integrated platform during design and operations of mega projects.  The Deep Lynx Core API delivers a few main features.  1. Provides a set of methods and endpoints for manipulating data in an object oriented database. This allows us to store complex datatypes as records and then to compile them into actual, modifiable objects at run-time. Users can store taxonomies or ontologies in a readable format.  2. Provides methods for storing and retrieving data in a graph database. This data is structured and validated against the aformentioned object oriented database before storage.  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import models into model package
from swagger_client.models.add_data_to_import_response import AddDataToImportResponse
from swagger_client.models.assign_role_request import AssignRoleRequest
from swagger_client.models.batch_container_update_request import BatchContainerUpdateRequest
from swagger_client.models.batch_update_container_response import BatchUpdateContainerResponse
from swagger_client.models.challenge import Challenge
from swagger_client.models.challenge_methods import ChallengeMethods
from swagger_client.models.container import Container
from swagger_client.models.container_config import ContainerConfig
from swagger_client.models.container_import_request import ContainerImportRequest
from swagger_client.models.container_import_response import ContainerImportResponse
from swagger_client.models.container_import_update_response import ContainerImportUpdateResponse
from swagger_client.models.container_invite import ContainerInvite
from swagger_client.models.containers_datasources_imports_request import ContainersDatasourcesImportsRequest
from swagger_client.models.containers_import_body import ContainersImportBody
from swagger_client.models.containers_query_response import ContainersQueryResponse
from swagger_client.models.context import Context
from swagger_client.models.create_container_request import CreateContainerRequest
from swagger_client.models.create_container_response import CreateContainerResponse
from swagger_client.models.create_data_source_config import CreateDataSourceConfig
from swagger_client.models.create_data_source_request import CreateDataSourceRequest
from swagger_client.models.create_data_sources_response import CreateDataSourcesResponse
from swagger_client.models.create_event_response import CreateEventResponse
from swagger_client.models.create_import_response import CreateImportResponse
from swagger_client.models.create_manual_import import CreateManualImport
from swagger_client.models.create_manual_import_response import CreateManualImportResponse
from swagger_client.models.create_metatype_keys_response import CreateMetatypeKeysResponse
from swagger_client.models.create_metatype_relationship_keys_response import CreateMetatypeRelationshipKeysResponse
from swagger_client.models.create_metatype_relationship_pairs_response import CreateMetatypeRelationshipPairsResponse
from swagger_client.models.create_metatype_relationships_response import CreateMetatypeRelationshipsResponse
from swagger_client.models.create_metatypes_response import CreateMetatypesResponse
from swagger_client.models.create_or_update_edges_request import CreateOrUpdateEdgesRequest
from swagger_client.models.create_or_update_nodes_request import CreateOrUpdateNodesRequest
from swagger_client.models.create_registered_event_request import CreateRegisteredEventRequest
from swagger_client.models.create_transformation_response import CreateTransformationResponse
from swagger_client.models.create_type_mapping_transformations_request import CreateTypeMappingTransformationsRequest
from swagger_client.models.credential_validation_result import CredentialValidationResult
from swagger_client.models.data_export_config import DataExportConfig
from swagger_client.models.data_source import DataSource
from swagger_client.models.data_source_config import DataSourceConfig
from swagger_client.models.data_source_id_files_body import DataSourceIdFilesBody
from swagger_client.models.data_source_import import DataSourceImport
from swagger_client.models.data_staging import DataStaging
from swagger_client.models.edge import Edge
from swagger_client.models.error_model import ErrorModel
from swagger_client.models.error_response import ErrorResponse
from swagger_client.models.event import Event
from swagger_client.models.exporter import Exporter
from swagger_client.models.exporter_config import ExporterConfig
from swagger_client.models.file_info import FileInfo
from swagger_client.models.file_model import FileModel
from swagger_client.models.generic200_response import Generic200Response
from swagger_client.models.get_container_response import GetContainerResponse
from swagger_client.models.get_data_export_response import GetDataExportResponse
from swagger_client.models.get_data_source_response import GetDataSourceResponse
from swagger_client.models.get_data_type_mapping_response import GetDataTypeMappingResponse
from swagger_client.models.get_edge_response import GetEdgeResponse
from swagger_client.models.get_event_response import GetEventResponse
from swagger_client.models.get_file_info_response import GetFileInfoResponse
from swagger_client.models.get_import_data_response import GetImportDataResponse
from swagger_client.models.get_metatype_key_response import GetMetatypeKeyResponse
from swagger_client.models.get_metatype_relationship_key_response import GetMetatypeRelationshipKeyResponse
from swagger_client.models.get_metatype_relationship_pair_response import GetMetatypeRelationshipPairResponse
from swagger_client.models.get_metatype_relationship_response import GetMetatypeRelationshipResponse
from swagger_client.models.get_metatype_response import GetMetatypeResponse
from swagger_client.models.get_node_response import GetNodeResponse
from swagger_client.models.get_user_response import GetUserResponse
from swagger_client.models.import_container_id_body import ImportContainerIdBody
from swagger_client.models.import_id_data_body import ImportIdDataBody
from swagger_client.models.import_model import ImportModel
from swagger_client.models.inline_response200 import InlineResponse200
from swagger_client.models.key_validation import KeyValidation
from swagger_client.models.list_container_invites_response import ListContainerInvitesResponse
from swagger_client.models.list_container_response import ListContainerResponse
from swagger_client.models.list_data_exports_response import ListDataExportsResponse
from swagger_client.models.list_data_source_imports_response import ListDataSourceImportsResponse
from swagger_client.models.list_data_sources_response import ListDataSourcesResponse
from swagger_client.models.list_data_type_mapping_response import ListDataTypeMappingResponse
from swagger_client.models.list_edge_files import ListEdgeFiles
from swagger_client.models.list_edges_response import ListEdgesResponse
from swagger_client.models.list_events_response import ListEventsResponse
from swagger_client.models.list_import_data_response import ListImportDataResponse
from swagger_client.models.list_metatype_keys_response import ListMetatypeKeysResponse
from swagger_client.models.list_metatype_relationship_keys_response import ListMetatypeRelationshipKeysResponse
from swagger_client.models.list_metatype_relationship_pairs_response import ListMetatypeRelationshipPairsResponse
from swagger_client.models.list_metatype_relationships_response import ListMetatypeRelationshipsResponse
from swagger_client.models.list_metatypes_response import ListMetatypesResponse
from swagger_client.models.list_node_files import ListNodeFiles
from swagger_client.models.list_nodes_response import ListNodesResponse
from swagger_client.models.list_transformation_response import ListTransformationResponse
from swagger_client.models.list_user_invites_response import ListUserInvitesResponse
from swagger_client.models.list_user_permissions_response import ListUserPermissionsResponse
from swagger_client.models.list_user_roles import ListUserRoles
from swagger_client.models.list_users_for_container_response import ListUsersForContainerResponse
from swagger_client.models.list_users_response import ListUsersResponse
from swagger_client.models.mappings_import_body import MappingsImportBody
from swagger_client.models.metatype import Metatype
from swagger_client.models.metatype_key import MetatypeKey
from swagger_client.models.metatype_relationship import MetatypeRelationship
from swagger_client.models.new_data_export_request import NewDataExportRequest
from swagger_client.models.new_metatype_key_request import NewMetatypeKeyRequest
from swagger_client.models.new_metatype_relationship_key_request import NewMetatypeRelationshipKeyRequest
from swagger_client.models.new_metatype_relationship_pair_request import NewMetatypeRelationshipPairRequest
from swagger_client.models.new_metatype_relationship_request import NewMetatypeRelationshipRequest
from swagger_client.models.new_metatype_request import NewMetatypeRequest
from swagger_client.models.node import Node
from swagger_client.models.node_metatype_body import NodeMetatypeBody
from swagger_client.models.not_found404 import NotFound404
from swagger_client.models.one_ofinline_response200 import OneOfinlineResponse200
from swagger_client.models.prompt import Prompt
from swagger_client.models.rsa_cancel_request import RSACancelRequest
from swagger_client.models.rsa_init_request import RSAInitRequest
from swagger_client.models.rsa_response import RSAResponse
from swagger_client.models.rsa_status_request import RSAStatusRequest
from swagger_client.models.rsa_status_response import RSAStatusResponse
from swagger_client.models.rsa_verify_request import RSAVerifyRequest
from swagger_client.models.relationship_key import RelationshipKey
from swagger_client.models.relationship_pair import RelationshipPair
from swagger_client.models.required_method import RequiredMethod
from swagger_client.models.token_exchange_request import TokenExchangeRequest
from swagger_client.models.transformation import Transformation
from swagger_client.models.transformation_condition import TransformationCondition
from swagger_client.models.transformation_key import TransformationKey
from swagger_client.models.type_mapping import TypeMapping
from swagger_client.models.type_mapping_export_payload import TypeMappingExportPayload
from swagger_client.models.update_container_request import UpdateContainerRequest
from swagger_client.models.update_container_response import UpdateContainerResponse
from swagger_client.models.update_data_source_response import UpdateDataSourceResponse
from swagger_client.models.update_data_type_mapping_response import UpdateDataTypeMappingResponse
from swagger_client.models.update_import_data_response import UpdateImportDataResponse
from swagger_client.models.update_metatype_key_request import UpdateMetatypeKeyRequest
from swagger_client.models.update_metatype_key_response import UpdateMetatypeKeyResponse
from swagger_client.models.update_metatype_relationship_key_response import UpdateMetatypeRelationshipKeyResponse
from swagger_client.models.update_metatype_relationship_pair_response import UpdateMetatypeRelationshipPairResponse
from swagger_client.models.update_metatype_relationship_request import UpdateMetatypeRelationshipRequest
from swagger_client.models.update_metatype_relationship_response import UpdateMetatypeRelationshipResponse
from swagger_client.models.update_metatype_request import UpdateMetatypeRequest
from swagger_client.models.update_metatype_response import UpdateMetatypeResponse
from swagger_client.models.update_registered_event_request import UpdateRegisteredEventRequest
from swagger_client.models.update_transformation_response import UpdateTransformationResponse
from swagger_client.models.upload_file_response import UploadFileResponse
from swagger_client.models.user import User
from swagger_client.models.user_key import UserKey
from swagger_client.models.validate_metatype_properties_response import ValidateMetatypePropertiesResponse
from swagger_client.models.validation import Validation
from swagger_client.models.value import Value
from swagger_client.models.version import Version



# coding: utf-8

"""
    Deep Lynx

    The construction of megaprojects has consistently demonstrated challenges for project managers in regard to meeting cost, schedule, and performance requirements. Megaproject construction challenges are common place within megaprojects with many active projects in the United States failing to meet cost and schedule efforts by significant margins. Currently, engineering teams operate in siloed tools and disparate teams where connections across design, procurement, and construction systems are translated manually or over brittle point-to-point integrations. The manual nature of data exchange increases the risk of silent errors in the reactor design, with each silent error cascading across the design. These cascading errors lead to uncontrollable risk during construction, resulting in significant delays and cost overruns. Deep Lynx allows for an integrated platform during design and operations of mega projects.  The Deep Lynx Core API delivers a few main features.  1. Provides a set of methods and endpoints for manipulating data in an object oriented database. This allows us to store complex datatypes as records and then to compile them into actual, modifiable objects at run-time. Users can store taxonomies or ontologies in a readable format.  2. Provides methods for storing and retrieving data in a graph database. This data is structured and validated against the aformentioned object oriented database before storage.  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from swagger_client.api_client import ApiClient


class MetatypeRelationshipsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def archive_metatype_relationship(self, container_id, relationship_id, **kwargs):  # noqa: E501
        """ArchiveMetatypeRelationship  # noqa: E501

        Archive the metatype relationship.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.archive_metatype_relationship(container_id, relationship_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str relationship_id: (required)
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.archive_metatype_relationship_with_http_info(container_id, relationship_id, **kwargs)  # noqa: E501
        else:
            (data) = self.archive_metatype_relationship_with_http_info(container_id, relationship_id, **kwargs)  # noqa: E501
            return data

    def archive_metatype_relationship_with_http_info(self, container_id, relationship_id, **kwargs):  # noqa: E501
        """ArchiveMetatypeRelationship  # noqa: E501

        Archive the metatype relationship.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.archive_metatype_relationship_with_http_info(container_id, relationship_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str relationship_id: (required)
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'relationship_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method archive_metatype_relationship" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `archive_metatype_relationship`")  # noqa: E501
        # verify the required parameter 'relationship_id' is set
        if ('relationship_id' not in params or
                params['relationship_id'] is None):
            raise ValueError("Missing the required parameter `relationship_id` when calling `archive_metatype_relationship`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'relationship_id' in params:
            path_params['relationship_id'] = params['relationship_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['httpBearer']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/metatype_relationships/{relationship_id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Generic200Response',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_metatype_relationship(self, body, container_id, **kwargs):  # noqa: E501
        """CreateMetatypeRelationship  # noqa: E501

        Create a new metatype relationship. Describes the connection that could exist between two metatypes and acts as a vehicle for relationship specific keys.  Pass in an array for bulk creation.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_metatype_relationship(body, container_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param NewMetatypeRelationshipRequest body: (required)
        :param str container_id: (required)
        :return: CreateMetatypeRelationshipsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_metatype_relationship_with_http_info(body, container_id, **kwargs)  # noqa: E501
        else:
            (data) = self.create_metatype_relationship_with_http_info(body, container_id, **kwargs)  # noqa: E501
            return data

    def create_metatype_relationship_with_http_info(self, body, container_id, **kwargs):  # noqa: E501
        """CreateMetatypeRelationship  # noqa: E501

        Create a new metatype relationship. Describes the connection that could exist between two metatypes and acts as a vehicle for relationship specific keys.  Pass in an array for bulk creation.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_metatype_relationship_with_http_info(body, container_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param NewMetatypeRelationshipRequest body: (required)
        :param str container_id: (required)
        :return: CreateMetatypeRelationshipsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'container_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_metatype_relationship" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_metatype_relationship`")  # noqa: E501
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `create_metatype_relationship`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['httpBearer']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/metatype_relationships', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateMetatypeRelationshipsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_metatype_relationships(self, container_id, **kwargs):  # noqa: E501
        """ListMetatypeRelationships  # noqa: E501

        List metatype relationships. Describes the connection between two metatypes and acts as a vehicle for relationship specific keys.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_metatype_relationships(container_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param int limit:
        :param int offset:
        :param str name: Filter metatype relationships with names that match this pattern
        :param str description: Filter metatype relationships with descriptions that match this pattern
        :param str archived: Set to true to include archived metatype relationships
        :param str count: Set to true to return an integer count of the number of metatype relationships
        :param str load_keys: Set to false to not return the keys for the selected metatype relationships (true by default)
        :param str sort_by: Supply the name of a metatype relationship attribute (name, created_at, etc) by which to sort
        :param str sort_desc: Set true to sort descending
        :return: ListMetatypeRelationshipsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_metatype_relationships_with_http_info(container_id, **kwargs)  # noqa: E501
        else:
            (data) = self.list_metatype_relationships_with_http_info(container_id, **kwargs)  # noqa: E501
            return data

    def list_metatype_relationships_with_http_info(self, container_id, **kwargs):  # noqa: E501
        """ListMetatypeRelationships  # noqa: E501

        List metatype relationships. Describes the connection between two metatypes and acts as a vehicle for relationship specific keys.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_metatype_relationships_with_http_info(container_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param int limit:
        :param int offset:
        :param str name: Filter metatype relationships with names that match this pattern
        :param str description: Filter metatype relationships with descriptions that match this pattern
        :param str archived: Set to true to include archived metatype relationships
        :param str count: Set to true to return an integer count of the number of metatype relationships
        :param str load_keys: Set to false to not return the keys for the selected metatype relationships (true by default)
        :param str sort_by: Supply the name of a metatype relationship attribute (name, created_at, etc) by which to sort
        :param str sort_desc: Set true to sort descending
        :return: ListMetatypeRelationshipsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'limit', 'offset', 'name', 'description', 'archived', 'count', 'load_keys', 'sort_by', 'sort_desc']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_metatype_relationships" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `list_metatype_relationships`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501

        query_params = []
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'name' in params:
            query_params.append(('name', params['name']))  # noqa: E501
        if 'description' in params:
            query_params.append(('description', params['description']))  # noqa: E501
        if 'archived' in params:
            query_params.append(('archived', params['archived']))  # noqa: E501
        if 'count' in params:
            query_params.append(('count', params['count']))  # noqa: E501
        if 'load_keys' in params:
            query_params.append(('loadKeys', params['load_keys']))  # noqa: E501
        if 'sort_by' in params:
            query_params.append(('sortBy', params['sort_by']))  # noqa: E501
        if 'sort_desc' in params:
            query_params.append(('sortDesc', params['sort_desc']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['httpBearer']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/metatype_relationships', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListMetatypeRelationshipsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retrieve_metatype_relationship(self, container_id, relationship_id, **kwargs):  # noqa: E501
        """RetrieveMetatypeRelationship  # noqa: E501

        Retrieve a single Metatype Relationship.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_metatype_relationship(container_id, relationship_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str relationship_id: (required)
        :return: GetMetatypeRelationshipResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.retrieve_metatype_relationship_with_http_info(container_id, relationship_id, **kwargs)  # noqa: E501
        else:
            (data) = self.retrieve_metatype_relationship_with_http_info(container_id, relationship_id, **kwargs)  # noqa: E501
            return data

    def retrieve_metatype_relationship_with_http_info(self, container_id, relationship_id, **kwargs):  # noqa: E501
        """RetrieveMetatypeRelationship  # noqa: E501

        Retrieve a single Metatype Relationship.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_metatype_relationship_with_http_info(container_id, relationship_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str relationship_id: (required)
        :return: GetMetatypeRelationshipResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'relationship_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_metatype_relationship" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `retrieve_metatype_relationship`")  # noqa: E501
        # verify the required parameter 'relationship_id' is set
        if ('relationship_id' not in params or
                params['relationship_id'] is None):
            raise ValueError("Missing the required parameter `relationship_id` when calling `retrieve_metatype_relationship`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'relationship_id' in params:
            path_params['relationship_id'] = params['relationship_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['httpBearer']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/metatype_relationships/{relationship_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetMetatypeRelationshipResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_metatype_relationship(self, body, container_id, relationship_id, **kwargs):  # noqa: E501
        """UpdateMetatypeRelationship  # noqa: E501

        Updates the specified metatype relationship.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_metatype_relationship(body, container_id, relationship_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateMetatypeRelationshipRequest body: (required)
        :param str container_id: (required)
        :param str relationship_id: (required)
        :return: UpdateMetatypeRelationshipResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_metatype_relationship_with_http_info(body, container_id, relationship_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_metatype_relationship_with_http_info(body, container_id, relationship_id, **kwargs)  # noqa: E501
            return data

    def update_metatype_relationship_with_http_info(self, body, container_id, relationship_id, **kwargs):  # noqa: E501
        """UpdateMetatypeRelationship  # noqa: E501

        Updates the specified metatype relationship.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_metatype_relationship_with_http_info(body, container_id, relationship_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateMetatypeRelationshipRequest body: (required)
        :param str container_id: (required)
        :param str relationship_id: (required)
        :return: UpdateMetatypeRelationshipResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'container_id', 'relationship_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_metatype_relationship" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_metatype_relationship`")  # noqa: E501
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `update_metatype_relationship`")  # noqa: E501
        # verify the required parameter 'relationship_id' is set
        if ('relationship_id' not in params or
                params['relationship_id'] is None):
            raise ValueError("Missing the required parameter `relationship_id` when calling `update_metatype_relationship`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'relationship_id' in params:
            path_params['relationship_id'] = params['relationship_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['httpBearer']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/metatype_relationships/{relationship_id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UpdateMetatypeRelationshipResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Deep Lynx

    The construction of megaprojects has consistently demonstrated challenges for project managers in regard to meeting cost, schedule, and performance requirements. Megaproject construction challenges are common place within megaprojects with many active projects in the United States failing to meet cost and schedule efforts by significant margins. Currently, engineering teams operate in siloed tools and disparate teams where connections across design, procurement, and construction systems are translated manually or over brittle point-to-point integrations. The manual nature of data exchange increases the risk of silent errors in the reactor design, with each silent error cascading across the design. These cascading errors lead to uncontrollable risk during construction, resulting in significant delays and cost overruns. Deep Lynx allows for an integrated platform during design and operations of mega projects.  The Deep Lynx Core API delivers a few main features.  1. Provides a set of methods and endpoints for manipulating data in an object oriented database. This allows us to store complex datatypes as records and then to compile them into actual, modifiable objects at run-time. Users can store taxonomies or ontologies in a readable format.  2. Provides methods for storing and retrieving data in a graph database. This data is structured and validated against the aformentioned object oriented database before storage.  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.data_type_mappings_api import DataTypeMappingsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestDataTypeMappingsApi(unittest.TestCase):
    """DataTypeMappingsApi unit test stubs"""

    def setUp(self):
        self.api = DataTypeMappingsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_transformation(self):
        """Test case for create_transformation

        CreateTransformation  # noqa: E501
        """
        pass

    def test_delete_data_type_mapping(self):
        """Test case for delete_data_type_mapping

        DeleteDataTypeMapping  # noqa: E501
        """
        pass

    def test_delete_transformation(self):
        """Test case for delete_transformation

        DeleteTransformation  # noqa: E501
        """
        pass

    def test_export_type_mappings(self):
        """Test case for export_type_mappings

        ExportTypeMappings  # noqa: E501
        """
        pass

    def test_import_data_type_mappings(self):
        """Test case for import_data_type_mappings

        ImportDataTypeMappings  # noqa: E501
        """
        pass

    def test_list_data_type_mappings(self):
        """Test case for list_data_type_mappings

        ListDataTypeMappings  # noqa: E501
        """
        pass

    def test_list_transformations(self):
        """Test case for list_transformations

        ListTransformations  # noqa: E501
        """
        pass

    def test_retrieve_data_type_mapping(self):
        """Test case for retrieve_data_type_mapping

        RetrieveDataTypeMapping  # noqa: E501
        """
        pass

    def test_update_data_type_mapping(self):
        """Test case for update_data_type_mapping

        UpdateDataTypeMapping  # noqa: E501
        """
        pass

    def test_update_transformation(self):
        """Test case for update_transformation

        UpdateTransformation  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Deep Lynx

    The construction of megaprojects has consistently demonstrated challenges for project managers in regard to meeting cost, schedule, and performance requirements. Megaproject construction challenges are common place within megaprojects with many active projects in the United States failing to meet cost and schedule efforts by significant margins. Currently, engineering teams operate in siloed tools and disparate teams where connections across design, procurement, and construction systems are translated manually or over brittle point-to-point integrations. The manual nature of data exchange increases the risk of silent errors in the reactor design, with each silent error cascading across the design. These cascading errors lead to uncontrollable risk during construction, resulting in significant delays and cost overruns. Deep Lynx allows for an integrated platform during design and operations of mega projects.  The Deep Lynx Core API delivers a few main features.  1. Provides a set of methods and endpoints for manipulating data in an object oriented database. This allows us to store complex datatypes as records and then to compile them into actual, modifiable objects at run-time. Users can store taxonomies or ontologies in a readable format.  2. Provides methods for storing and retrieving data in a graph database. This data is structured and validated against the aformentioned object oriented database before storage.  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import
from os import getenv
from dotenv import load_dotenv

import unittest
from deep_lynx.configuration import Configuration
from deep_lynx.models.create_container_request import CreateContainerRequest
from deep_lynx.models.create_container_response import CreateContainerResponse
from deep_lynx.models.create_data_source_request import CreateDataSourceRequest
from deep_lynx.models.token_exchange_request import TokenExchangeRequest

import swagger_client
import deep_lynx
from swagger_client.models.create_manual_import import CreateManualImport  # noqa: E501
from swagger_client.rest import ApiException


class TestCreateManualImport(unittest.TestCase):
    """CreateManualImport unit test stubs"""

    # API Setup
    configuration = Configuration()
    configuration.host = 'http://localhost:8090'
    apiClient = deep_lynx.ApiClient(configuration)

    containerApi = deep_lynx.ContainersApi(apiClient)
    containerId = ''

    def setUp(self):
        load_dotenv()
        if getenv('API_KEY') is None or getenv('API_SECRET') is None:
            print("""Please supply API key and secret.
Have you copied the .env-sample and created .env?
Skipping all tests in test_create_manual_import.py""")
            raise unittest.SkipTest("""Please supply API key and secret.
                Have you copied the .env-sample and created .env?
                Skipping all tests in test_create_manual_import.py""")
                
        if getenv('API_KEY') == '' or getenv('API_SECRET') == '':
            print("""Please supply API key and secret.
Skipping all tests in test_create_manual_import.py""")
            raise unittest.SkipTest("""Please supply API key and secret.
                Skipping all tests in test_create_manual_import.py""")
        pass

    def tearDown(self):
        if self.containerId != '':
            self.containerApi.archive_container(self.containerId, permanent=True)
            print('Successfully removed test container')
        pass

    def testCreateManualImport(self):
        """Test CreateManualImport"""
        # Verify API keys have been provided
        apiKey = getenv('API_KEY')
        apiSecret = getenv('API_SECRET')

        # Authenticate
        authApi = deep_lynx.AuthenticationApi(self.apiClient)

        token = authApi.retrieve_o_auth_token(x_api_key=apiKey, x_api_secret=apiSecret, x_api_expiry='1h')
        self.assertIsNotNone(token)

        container = self.containerApi.create_container(CreateContainerRequest(
            'sdk_test', 'Test container description', False
        ))
        self.assertIsNotNone(container.value[0].id)
        self.containerId = container.value[0].id

        # Create Data Source
        datasourcesApi = deep_lynx.DataSourcesApi(self.apiClient)

        datasource = datasourcesApi.create_data_source(CreateDataSourceRequest(
            'sdk_test_source', 'standard', True
        ), self.containerId)
        self.assertIsNotNone(datasource.value.id)
        datasourceId = datasource.value.id

        # Create Manual Import
        importResult = datasourcesApi.create_manual_import(
            {'test': 'test import'},
            self.containerId,
            datasourceId
        )
        self.assertIsNotNone(importResult.value)

        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Deep Lynx

    The construction of megaprojects has consistently demonstrated challenges for project managers in regard to meeting cost, schedule, and performance requirements. Megaproject construction challenges are common place within megaprojects with many active projects in the United States failing to meet cost and schedule efforts by significant margins. Currently, engineering teams operate in siloed tools and disparate teams where connections across design, procurement, and construction systems are translated manually or over brittle point-to-point integrations. The manual nature of data exchange increases the risk of silent errors in the reactor design, with each silent error cascading across the design. These cascading errors lead to uncontrollable risk during construction, resulting in significant delays and cost overruns. Deep Lynx allows for an integrated platform during design and operations of mega projects.  The Deep Lynx Core API delivers a few main features.  1. Provides a set of methods and endpoints for manipulating data in an object oriented database. This allows us to store complex datatypes as records and then to compile them into actual, modifiable objects at run-time. Users can store taxonomies or ontologies in a readable format.  2. Provides methods for storing and retrieving data in a graph database. This data is structured and validated against the aformentioned object oriented database before storage.  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ImportIdDataBody(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'file': 'str'
    }

    attribute_map = {
        'file': 'file'
    }

    def __init__(self, file=None):  # noqa: E501
        """ImportIdDataBody - a model defined in Swagger"""  # noqa: E501
        self._file = None
        self.discriminator = None
        if file is not None:
            self.file = file

    @property
    def file(self):
        """Gets the file of this ImportIdDataBody.  # noqa: E501


        :return: The file of this ImportIdDataBody.  # noqa: E501
        :rtype: str
        """
        return self._file

    @file.setter
    def file(self, file):
        """Sets the file of this ImportIdDataBody.


        :param file: The file of this ImportIdDataBody.  # noqa: E501
        :type: str
        """

        self._file = file

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ImportIdDataBody, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ImportIdDataBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Deep Lynx

    The construction of megaprojects has consistently demonstrated challenges for project managers in regard to meeting cost, schedule, and performance requirements. Megaproject construction challenges are common place within megaprojects with many active projects in the United States failing to meet cost and schedule efforts by significant margins. Currently, engineering teams operate in siloed tools and disparate teams where connections across design, procurement, and construction systems are translated manually or over brittle point-to-point integrations. The manual nature of data exchange increases the risk of silent errors in the reactor design, with each silent error cascading across the design. These cascading errors lead to uncontrollable risk during construction, resulting in significant delays and cost overruns. Deep Lynx allows for an integrated platform during design and operations of mega projects.  The Deep Lynx Core API delivers a few main features.  1. Provides a set of methods and endpoints for manipulating data in an object oriented database. This allows us to store complex datatypes as records and then to compile them into actual, modifiable objects at run-time. Users can store taxonomies or ontologies in a readable format.  2. Provides methods for storing and retrieving data in a graph database. This data is structured and validated against the aformentioned object oriented database before storage.  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from deep_lynx.api_client import ApiClient


class EventsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_registered_event(self, body, **kwargs):  # noqa: E501
        """Create Registered Event  # noqa: E501

        Create new registered event. An `app_name`, `app_url`, and `event_type` must be provided. Either a `container_id` or `data_source_id` must also be provided.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_registered_event(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateRegisteredEventRequest body: (required)
        :return: CreateEventResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_registered_event_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.create_registered_event_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def create_registered_event_with_http_info(self, body, **kwargs):  # noqa: E501
        """Create Registered Event  # noqa: E501

        Create new registered event. An `app_name`, `app_url`, and `event_type` must be provided. Either a `container_id` or `data_source_id` must also be provided.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_registered_event_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateRegisteredEventRequest body: (required)
        :return: CreateEventResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_registered_event" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_registered_event`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/events', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateEventResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_registered_event(self, event_id, **kwargs):  # noqa: E501
        """Delete Registered Event  # noqa: E501

        Delete a registered event.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_registered_event(event_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str event_id: (required)
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_registered_event_with_http_info(event_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_registered_event_with_http_info(event_id, **kwargs)  # noqa: E501
            return data

    def delete_registered_event_with_http_info(self, event_id, **kwargs):  # noqa: E501
        """Delete Registered Event  # noqa: E501

        Delete a registered event.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_registered_event_with_http_info(event_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str event_id: (required)
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['event_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_registered_event" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'event_id' is set
        if ('event_id' not in params or
                params['event_id'] is None):
            raise ValueError("Missing the required parameter `event_id` when calling `delete_registered_event`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'event_id' in params:
            path_params['event_id'] = params['event_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/events/{event_id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Generic200Response',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_registered_events(self, **kwargs):  # noqa: E501
        """List Registered Events  # noqa: E501

        Lists all registered events  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_registered_events(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: ListEventsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_registered_events_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.list_registered_events_with_http_info(**kwargs)  # noqa: E501
            return data

    def list_registered_events_with_http_info(self, **kwargs):  # noqa: E501
        """List Registered Events  # noqa: E501

        Lists all registered events  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_registered_events_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: ListEventsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_registered_events" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/events', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListEventsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retrieve_registered_event(self, event_id, **kwargs):  # noqa: E501
        """Retrieve Registered Event  # noqa: E501

        Retrieve a registered event  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_registered_event(event_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str event_id: (required)
        :return: GetEventResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.retrieve_registered_event_with_http_info(event_id, **kwargs)  # noqa: E501
        else:
            (data) = self.retrieve_registered_event_with_http_info(event_id, **kwargs)  # noqa: E501
            return data

    def retrieve_registered_event_with_http_info(self, event_id, **kwargs):  # noqa: E501
        """Retrieve Registered Event  # noqa: E501

        Retrieve a registered event  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_registered_event_with_http_info(event_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str event_id: (required)
        :return: GetEventResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['event_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_registered_event" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'event_id' is set
        if ('event_id' not in params or
                params['event_id'] is None):
            raise ValueError("Missing the required parameter `event_id` when calling `retrieve_registered_event`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'event_id' in params:
            path_params['event_id'] = params['event_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/events/{event_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetEventResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_registered_event(self, event_id, **kwargs):  # noqa: E501
        """Update Registered Event  # noqa: E501

        Update a registered event. If the `active` query paramter is provided with a value of true or false, the event will be activated/deactivated.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_registered_event(event_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str event_id: (required)
        :param UpdateRegisteredEventRequest body:
        :param bool active:
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_registered_event_with_http_info(event_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_registered_event_with_http_info(event_id, **kwargs)  # noqa: E501
            return data

    def update_registered_event_with_http_info(self, event_id, **kwargs):  # noqa: E501
        """Update Registered Event  # noqa: E501

        Update a registered event. If the `active` query paramter is provided with a value of true or false, the event will be activated/deactivated.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_registered_event_with_http_info(event_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str event_id: (required)
        :param UpdateRegisteredEventRequest body:
        :param bool active:
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['event_id', 'body', 'active']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_registered_event" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'event_id' is set
        if ('event_id' not in params or
                params['event_id'] is None):
            raise ValueError("Missing the required parameter `event_id` when calling `update_registered_event`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'event_id' in params:
            path_params['event_id'] = params['event_id']  # noqa: E501

        query_params = []
        if 'active' in params:
            query_params.append(('active', params['active']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/events/{event_id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Generic200Response',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Deep Lynx

    The construction of megaprojects has consistently demonstrated challenges for project managers in regard to meeting cost, schedule, and performance requirements. Megaproject construction challenges are common place within megaprojects with many active projects in the United States failing to meet cost and schedule efforts by significant margins. Currently, engineering teams operate in siloed tools and disparate teams where connections across design, procurement, and construction systems are translated manually or over brittle point-to-point integrations. The manual nature of data exchange increases the risk of silent errors in the reactor design, with each silent error cascading across the design. These cascading errors lead to uncontrollable risk during construction, resulting in significant delays and cost overruns. Deep Lynx allows for an integrated platform during design and operations of mega projects.  The Deep Lynx Core API delivers a few main features.  1. Provides a set of methods and endpoints for manipulating data in an object oriented database. This allows us to store complex datatypes as records and then to compile them into actual, modifiable objects at run-time. Users can store taxonomies or ontologies in a readable format.  2. Provides methods for storing and retrieving data in a graph database. This data is structured and validated against the aformentioned object oriented database before storage.  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Exporter(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'adapter': 'str',
        'status': 'str',
        'config': 'ExporterConfig',
        'id': 'str',
        'container_id': 'str',
        'created_at': 'str',
        'modified_at': 'str',
        'created_by': 'str',
        'modified_by': 'str',
        'status_message': 'str',
        'destination_type': 'str'
    }

    attribute_map = {
        'adapter': 'adapter',
        'status': 'status',
        'config': 'config',
        'id': 'id',
        'container_id': 'container_id',
        'created_at': 'created_at',
        'modified_at': 'modified_at',
        'created_by': 'created_by',
        'modified_by': 'modified_by',
        'status_message': 'status_message',
        'destination_type': 'destination_type'
    }

    def __init__(self, adapter=None, status=None, config=None, id=None, container_id=None, created_at=None, modified_at=None, created_by=None, modified_by=None, status_message=None, destination_type=None):  # noqa: E501
        """Exporter - a model defined in Swagger"""  # noqa: E501
        self._adapter = None
        self._status = None
        self._config = None
        self._id = None
        self._container_id = None
        self._created_at = None
        self._modified_at = None
        self._created_by = None
        self._modified_by = None
        self._status_message = None
        self._destination_type = None
        self.discriminator = None
        self.adapter = adapter
        self.status = status
        self.config = config
        self.id = id
        self.container_id = container_id
        self.created_at = created_at
        self.modified_at = modified_at
        self.created_by = created_by
        self.modified_by = modified_by
        if status_message is not None:
            self.status_message = status_message
        if destination_type is not None:
            self.destination_type = destination_type

    @property
    def adapter(self):
        """Gets the adapter of this Exporter.  # noqa: E501


        :return: The adapter of this Exporter.  # noqa: E501
        :rtype: str
        """
        return self._adapter

    @adapter.setter
    def adapter(self, adapter):
        """Sets the adapter of this Exporter.


        :param adapter: The adapter of this Exporter.  # noqa: E501
        :type: str
        """
        if adapter is None:
            raise ValueError("Invalid value for `adapter`, must not be `None`")  # noqa: E501

        self._adapter = adapter

    @property
    def status(self):
        """Gets the status of this Exporter.  # noqa: E501


        :return: The status of this Exporter.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Exporter.


        :param status: The status of this Exporter.  # noqa: E501
        :type: str
        """
        if status is None:
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    @property
    def config(self):
        """Gets the config of this Exporter.  # noqa: E501


        :return: The config of this Exporter.  # noqa: E501
        :rtype: ExporterConfig
        """
        return self._config

    @config.setter
    def config(self, config):
        """Sets the config of this Exporter.


        :param config: The config of this Exporter.  # noqa: E501
        :type: ExporterConfig
        """
        if config is None:
            raise ValueError("Invalid value for `config`, must not be `None`")  # noqa: E501

        self._config = config

    @property
    def id(self):
        """Gets the id of this Exporter.  # noqa: E501


        :return: The id of this Exporter.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Exporter.


        :param id: The id of this Exporter.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def container_id(self):
        """Gets the container_id of this Exporter.  # noqa: E501


        :return: The container_id of this Exporter.  # noqa: E501
        :rtype: str
        """
        return self._container_id

    @container_id.setter
    def container_id(self, container_id):
        """Sets the container_id of this Exporter.


        :param container_id: The container_id of this Exporter.  # noqa: E501
        :type: str
        """
        if container_id is None:
            raise ValueError("Invalid value for `container_id`, must not be `None`")  # noqa: E501

        self._container_id = container_id

    @property
    def created_at(self):
        """Gets the created_at of this Exporter.  # noqa: E501


        :return: The created_at of this Exporter.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Exporter.


        :param created_at: The created_at of this Exporter.  # noqa: E501
        :type: str
        """
        if created_at is None:
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def modified_at(self):
        """Gets the modified_at of this Exporter.  # noqa: E501


        :return: The modified_at of this Exporter.  # noqa: E501
        :rtype: str
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this Exporter.


        :param modified_at: The modified_at of this Exporter.  # noqa: E501
        :type: str
        """
        if modified_at is None:
            raise ValueError("Invalid value for `modified_at`, must not be `None`")  # noqa: E501

        self._modified_at = modified_at

    @property
    def created_by(self):
        """Gets the created_by of this Exporter.  # noqa: E501


        :return: The created_by of this Exporter.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this Exporter.


        :param created_by: The created_by of this Exporter.  # noqa: E501
        :type: str
        """
        if created_by is None:
            raise ValueError("Invalid value for `created_by`, must not be `None`")  # noqa: E501

        self._created_by = created_by

    @property
    def modified_by(self):
        """Gets the modified_by of this Exporter.  # noqa: E501


        :return: The modified_by of this Exporter.  # noqa: E501
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """Sets the modified_by of this Exporter.


        :param modified_by: The modified_by of this Exporter.  # noqa: E501
        :type: str
        """
        if modified_by is None:
            raise ValueError("Invalid value for `modified_by`, must not be `None`")  # noqa: E501

        self._modified_by = modified_by

    @property
    def status_message(self):
        """Gets the status_message of this Exporter.  # noqa: E501


        :return: The status_message of this Exporter.  # noqa: E501
        :rtype: str
        """
        return self._status_message

    @status_message.setter
    def status_message(self, status_message):
        """Sets the status_message of this Exporter.


        :param status_message: The status_message of this Exporter.  # noqa: E501
        :type: str
        """

        self._status_message = status_message

    @property
    def destination_type(self):
        """Gets the destination_type of this Exporter.  # noqa: E501


        :return: The destination_type of this Exporter.  # noqa: E501
        :rtype: str
        """
        return self._destination_type

    @destination_type.setter
    def destination_type(self, destination_type):
        """Sets the destination_type of this Exporter.


        :param destination_type: The destination_type of this Exporter.  # noqa: E501
        :type: str
        """

        self._destination_type = destination_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Exporter, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Exporter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Deep Lynx

    The construction of megaprojects has consistently demonstrated challenges for project managers in regard to meeting cost, schedule, and performance requirements. Megaproject construction challenges are common place within megaprojects with many active projects in the United States failing to meet cost and schedule efforts by significant margins. Currently, engineering teams operate in siloed tools and disparate teams where connections across design, procurement, and construction systems are translated manually or over brittle point-to-point integrations. The manual nature of data exchange increases the risk of silent errors in the reactor design, with each silent error cascading across the design. These cascading errors lead to uncontrollable risk during construction, resulting in significant delays and cost overruns. Deep Lynx allows for an integrated platform during design and operations of mega projects.  The Deep Lynx Core API delivers a few main features.  1. Provides a set of methods and endpoints for manipulating data in an object oriented database. This allows us to store complex datatypes as records and then to compile them into actual, modifiable objects at run-time. Users can store taxonomies or ontologies in a readable format.  2. Provides methods for storing and retrieving data in a graph database. This data is structured and validated against the aformentioned object oriented database before storage.  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from swagger_client.api_client import ApiClient


class DataTypeMappingsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_transformation(self, body, container_id, data_source_id, mapping_id, **kwargs):  # noqa: E501
        """CreateTransformation  # noqa: E501

        Create a transformation for the type mapping.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_transformation(body, container_id, data_source_id, mapping_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateTypeMappingTransformationsRequest body: (required)
        :param str container_id: (required)
        :param str data_source_id: (required)
        :param str mapping_id: (required)
        :return: CreateTransformationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_transformation_with_http_info(body, container_id, data_source_id, mapping_id, **kwargs)  # noqa: E501
        else:
            (data) = self.create_transformation_with_http_info(body, container_id, data_source_id, mapping_id, **kwargs)  # noqa: E501
            return data

    def create_transformation_with_http_info(self, body, container_id, data_source_id, mapping_id, **kwargs):  # noqa: E501
        """CreateTransformation  # noqa: E501

        Create a transformation for the type mapping.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_transformation_with_http_info(body, container_id, data_source_id, mapping_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateTypeMappingTransformationsRequest body: (required)
        :param str container_id: (required)
        :param str data_source_id: (required)
        :param str mapping_id: (required)
        :return: CreateTransformationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'container_id', 'data_source_id', 'mapping_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_transformation" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_transformation`")  # noqa: E501
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `create_transformation`")  # noqa: E501
        # verify the required parameter 'data_source_id' is set
        if ('data_source_id' not in params or
                params['data_source_id'] is None):
            raise ValueError("Missing the required parameter `data_source_id` when calling `create_transformation`")  # noqa: E501
        # verify the required parameter 'mapping_id' is set
        if ('mapping_id' not in params or
                params['mapping_id'] is None):
            raise ValueError("Missing the required parameter `mapping_id` when calling `create_transformation`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'data_source_id' in params:
            path_params['data_source_id'] = params['data_source_id']  # noqa: E501
        if 'mapping_id' in params:
            path_params['mapping_id'] = params['mapping_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['httpBearer']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/import/datasources/{data_source_id}/mappings/{mapping_id}/transformations', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateTransformationResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_data_type_mapping(self, container_id, data_source_id, mapping_id, **kwargs):  # noqa: E501
        """DeleteDataTypeMapping  # noqa: E501

        Permanently remove data type mapping.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_data_type_mapping(container_id, data_source_id, mapping_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str data_source_id: (required)
        :param str mapping_id: (required)
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_data_type_mapping_with_http_info(container_id, data_source_id, mapping_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_data_type_mapping_with_http_info(container_id, data_source_id, mapping_id, **kwargs)  # noqa: E501
            return data

    def delete_data_type_mapping_with_http_info(self, container_id, data_source_id, mapping_id, **kwargs):  # noqa: E501
        """DeleteDataTypeMapping  # noqa: E501

        Permanently remove data type mapping.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_data_type_mapping_with_http_info(container_id, data_source_id, mapping_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str data_source_id: (required)
        :param str mapping_id: (required)
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'data_source_id', 'mapping_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_data_type_mapping" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `delete_data_type_mapping`")  # noqa: E501
        # verify the required parameter 'data_source_id' is set
        if ('data_source_id' not in params or
                params['data_source_id'] is None):
            raise ValueError("Missing the required parameter `data_source_id` when calling `delete_data_type_mapping`")  # noqa: E501
        # verify the required parameter 'mapping_id' is set
        if ('mapping_id' not in params or
                params['mapping_id'] is None):
            raise ValueError("Missing the required parameter `mapping_id` when calling `delete_data_type_mapping`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'data_source_id' in params:
            path_params['data_source_id'] = params['data_source_id']  # noqa: E501
        if 'mapping_id' in params:
            path_params['mapping_id'] = params['mapping_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['httpBearer']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/import/datasources/{data_source_id}/mappings/{mapping_id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Generic200Response',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_transformation(self, container_id, data_source_id, mapping_id, transformation_id, **kwargs):  # noqa: E501
        """DeleteTransformation  # noqa: E501

        Delete a transformation.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_transformation(container_id, data_source_id, mapping_id, transformation_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str data_source_id: (required)
        :param str mapping_id: (required)
        :param str transformation_id: (required)
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_transformation_with_http_info(container_id, data_source_id, mapping_id, transformation_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_transformation_with_http_info(container_id, data_source_id, mapping_id, transformation_id, **kwargs)  # noqa: E501
            return data

    def delete_transformation_with_http_info(self, container_id, data_source_id, mapping_id, transformation_id, **kwargs):  # noqa: E501
        """DeleteTransformation  # noqa: E501

        Delete a transformation.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_transformation_with_http_info(container_id, data_source_id, mapping_id, transformation_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str data_source_id: (required)
        :param str mapping_id: (required)
        :param str transformation_id: (required)
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'data_source_id', 'mapping_id', 'transformation_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_transformation" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `delete_transformation`")  # noqa: E501
        # verify the required parameter 'data_source_id' is set
        if ('data_source_id' not in params or
                params['data_source_id'] is None):
            raise ValueError("Missing the required parameter `data_source_id` when calling `delete_transformation`")  # noqa: E501
        # verify the required parameter 'mapping_id' is set
        if ('mapping_id' not in params or
                params['mapping_id'] is None):
            raise ValueError("Missing the required parameter `mapping_id` when calling `delete_transformation`")  # noqa: E501
        # verify the required parameter 'transformation_id' is set
        if ('transformation_id' not in params or
                params['transformation_id'] is None):
            raise ValueError("Missing the required parameter `transformation_id` when calling `delete_transformation`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'data_source_id' in params:
            path_params['data_source_id'] = params['data_source_id']  # noqa: E501
        if 'mapping_id' in params:
            path_params['mapping_id'] = params['mapping_id']  # noqa: E501
        if 'transformation_id' in params:
            path_params['transformation_id'] = params['transformation_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['httpBearer']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/import/datasources/{data_source_id}/mappings/{mapping_id}/transformations/{transformation_id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Generic200Response',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def export_type_mappings(self, container_id, data_source_id, **kwargs):  # noqa: E501
        """ExportTypeMappings  # noqa: E501

        Export type mappings for a datasource. Providing a JSON body is optional. If provided, the mapping_ids may be specified to indicate certain type mapping IDs to return. Additionally, a target data source may be provided to which the mappings will be copied.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_type_mappings(container_id, data_source_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str data_source_id: (required)
        :param TypeMappingExportPayload body:
        :return: list[TypeMapping]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.export_type_mappings_with_http_info(container_id, data_source_id, **kwargs)  # noqa: E501
        else:
            (data) = self.export_type_mappings_with_http_info(container_id, data_source_id, **kwargs)  # noqa: E501
            return data

    def export_type_mappings_with_http_info(self, container_id, data_source_id, **kwargs):  # noqa: E501
        """ExportTypeMappings  # noqa: E501

        Export type mappings for a datasource. Providing a JSON body is optional. If provided, the mapping_ids may be specified to indicate certain type mapping IDs to return. Additionally, a target data source may be provided to which the mappings will be copied.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_type_mappings_with_http_info(container_id, data_source_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str data_source_id: (required)
        :param TypeMappingExportPayload body:
        :return: list[TypeMapping]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'data_source_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method export_type_mappings" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `export_type_mappings`")  # noqa: E501
        # verify the required parameter 'data_source_id' is set
        if ('data_source_id' not in params or
                params['data_source_id'] is None):
            raise ValueError("Missing the required parameter `data_source_id` when calling `export_type_mappings`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'data_source_id' in params:
            path_params['data_source_id'] = params['data_source_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['httpBearer']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/import/datasources/{data_source_id}/mappings/export', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[TypeMapping]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def import_data_type_mappings(self, container_id, data_source_id, **kwargs):  # noqa: E501
        """ImportDataTypeMappings  # noqa: E501

        Import type mappings for a datasource. Accepts either a JSON body or actual JSON file. The payload should be an array of type mapping classes, previously generated using the export route.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.import_data_type_mappings(container_id, data_source_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str data_source_id: (required)
        :param str file:
        :return: list[GetDataTypeMappingResponse]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.import_data_type_mappings_with_http_info(container_id, data_source_id, **kwargs)  # noqa: E501
        else:
            (data) = self.import_data_type_mappings_with_http_info(container_id, data_source_id, **kwargs)  # noqa: E501
            return data

    def import_data_type_mappings_with_http_info(self, container_id, data_source_id, **kwargs):  # noqa: E501
        """ImportDataTypeMappings  # noqa: E501

        Import type mappings for a datasource. Accepts either a JSON body or actual JSON file. The payload should be an array of type mapping classes, previously generated using the export route.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.import_data_type_mappings_with_http_info(container_id, data_source_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str data_source_id: (required)
        :param str file:
        :return: list[GetDataTypeMappingResponse]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'data_source_id', 'file']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method import_data_type_mappings" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `import_data_type_mappings`")  # noqa: E501
        # verify the required parameter 'data_source_id' is set
        if ('data_source_id' not in params or
                params['data_source_id'] is None):
            raise ValueError("Missing the required parameter `data_source_id` when calling `import_data_type_mappings`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'data_source_id' in params:
            path_params['data_source_id'] = params['data_source_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'file' in params:
            form_params.append(('file', params['file']))  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/x-www-form-urlencoded'])  # noqa: E501

        # Authentication setting
        auth_settings = ['httpBearer']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/import/datasources/{data_source_id}/mappings/import', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[GetDataTypeMappingResponse]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_data_type_mappings(self, container_id, data_source_id, **kwargs):  # noqa: E501
        """ListDataTypeMappings  # noqa: E501

        Lists data type mappings for the data source  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_data_type_mappings(container_id, data_source_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str data_source_id: (required)
        :param int limit:
        :param int offset:
        :param bool needs_transformations: boolean indicating if the return should consist of only mappings that need transformations
        :param bool count: boolean indicating if the return value should be a count only
        :param str sort_by: column to sort results by
        :param bool sort_desc: boolean indicating if results should be in descending order
        :param str resulting_metatype_name: if supplied, filters returned transformations by those that produce the resulting metatype
        :param str resulting_metatype_relationship_name: if supplied, filters returned transformations by those that produce the resulting metatype relationship
        :return: ListDataTypeMappingResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_data_type_mappings_with_http_info(container_id, data_source_id, **kwargs)  # noqa: E501
        else:
            (data) = self.list_data_type_mappings_with_http_info(container_id, data_source_id, **kwargs)  # noqa: E501
            return data

    def list_data_type_mappings_with_http_info(self, container_id, data_source_id, **kwargs):  # noqa: E501
        """ListDataTypeMappings  # noqa: E501

        Lists data type mappings for the data source  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_data_type_mappings_with_http_info(container_id, data_source_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str data_source_id: (required)
        :param int limit:
        :param int offset:
        :param bool needs_transformations: boolean indicating if the return should consist of only mappings that need transformations
        :param bool count: boolean indicating if the return value should be a count only
        :param str sort_by: column to sort results by
        :param bool sort_desc: boolean indicating if results should be in descending order
        :param str resulting_metatype_name: if supplied, filters returned transformations by those that produce the resulting metatype
        :param str resulting_metatype_relationship_name: if supplied, filters returned transformations by those that produce the resulting metatype relationship
        :return: ListDataTypeMappingResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'data_source_id', 'limit', 'offset', 'needs_transformations', 'count', 'sort_by', 'sort_desc', 'resulting_metatype_name', 'resulting_metatype_relationship_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_data_type_mappings" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `list_data_type_mappings`")  # noqa: E501
        # verify the required parameter 'data_source_id' is set
        if ('data_source_id' not in params or
                params['data_source_id'] is None):
            raise ValueError("Missing the required parameter `data_source_id` when calling `list_data_type_mappings`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'data_source_id' in params:
            path_params['data_source_id'] = params['data_source_id']  # noqa: E501

        query_params = []
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'needs_transformations' in params:
            query_params.append(('needsTransformations', params['needs_transformations']))  # noqa: E501
        if 'count' in params:
            query_params.append(('count', params['count']))  # noqa: E501
        if 'sort_by' in params:
            query_params.append(('sortBy', params['sort_by']))  # noqa: E501
        if 'sort_desc' in params:
            query_params.append(('sortDesc', params['sort_desc']))  # noqa: E501
        if 'resulting_metatype_name' in params:
            query_params.append(('resultingMetatypeName', params['resulting_metatype_name']))  # noqa: E501
        if 'resulting_metatype_relationship_name' in params:
            query_params.append(('resultingMetatypeRelationshipName', params['resulting_metatype_relationship_name']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['httpBearer']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/import/datasources/{data_source_id}/mappings', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListDataTypeMappingResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_transformations(self, container_id, data_source_id, mapping_id, **kwargs):  # noqa: E501
        """ListTransformations  # noqa: E501

        List transformations for a type mapping from storage.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_transformations(container_id, data_source_id, mapping_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str data_source_id: (required)
        :param str mapping_id: (required)
        :return: ListTransformationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_transformations_with_http_info(container_id, data_source_id, mapping_id, **kwargs)  # noqa: E501
        else:
            (data) = self.list_transformations_with_http_info(container_id, data_source_id, mapping_id, **kwargs)  # noqa: E501
            return data

    def list_transformations_with_http_info(self, container_id, data_source_id, mapping_id, **kwargs):  # noqa: E501
        """ListTransformations  # noqa: E501

        List transformations for a type mapping from storage.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_transformations_with_http_info(container_id, data_source_id, mapping_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str data_source_id: (required)
        :param str mapping_id: (required)
        :return: ListTransformationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'data_source_id', 'mapping_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_transformations" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `list_transformations`")  # noqa: E501
        # verify the required parameter 'data_source_id' is set
        if ('data_source_id' not in params or
                params['data_source_id'] is None):
            raise ValueError("Missing the required parameter `data_source_id` when calling `list_transformations`")  # noqa: E501
        # verify the required parameter 'mapping_id' is set
        if ('mapping_id' not in params or
                params['mapping_id'] is None):
            raise ValueError("Missing the required parameter `mapping_id` when calling `list_transformations`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'data_source_id' in params:
            path_params['data_source_id'] = params['data_source_id']  # noqa: E501
        if 'mapping_id' in params:
            path_params['mapping_id'] = params['mapping_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['httpBearer']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/import/datasources/{data_source_id}/mappings/{mapping_id}/transformations', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListTransformationResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retrieve_data_type_mapping(self, container_id, data_source_id, mapping_id, **kwargs):  # noqa: E501
        """RetrieveDataTypeMapping  # noqa: E501

        Retrieve a data type mapping  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_data_type_mapping(container_id, data_source_id, mapping_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str data_source_id: (required)
        :param str mapping_id: (required)
        :return: GetDataTypeMappingResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.retrieve_data_type_mapping_with_http_info(container_id, data_source_id, mapping_id, **kwargs)  # noqa: E501
        else:
            (data) = self.retrieve_data_type_mapping_with_http_info(container_id, data_source_id, mapping_id, **kwargs)  # noqa: E501
            return data

    def retrieve_data_type_mapping_with_http_info(self, container_id, data_source_id, mapping_id, **kwargs):  # noqa: E501
        """RetrieveDataTypeMapping  # noqa: E501

        Retrieve a data type mapping  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_data_type_mapping_with_http_info(container_id, data_source_id, mapping_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str data_source_id: (required)
        :param str mapping_id: (required)
        :return: GetDataTypeMappingResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'data_source_id', 'mapping_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_data_type_mapping" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `retrieve_data_type_mapping`")  # noqa: E501
        # verify the required parameter 'data_source_id' is set
        if ('data_source_id' not in params or
                params['data_source_id'] is None):
            raise ValueError("Missing the required parameter `data_source_id` when calling `retrieve_data_type_mapping`")  # noqa: E501
        # verify the required parameter 'mapping_id' is set
        if ('mapping_id' not in params or
                params['mapping_id'] is None):
            raise ValueError("Missing the required parameter `mapping_id` when calling `retrieve_data_type_mapping`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'data_source_id' in params:
            path_params['data_source_id'] = params['data_source_id']  # noqa: E501
        if 'mapping_id' in params:
            path_params['mapping_id'] = params['mapping_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['httpBearer']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/import/datasources/{data_source_id}/mappings/{mapping_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetDataTypeMappingResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_data_type_mapping(self, container_id, data_source_id, mapping_id, **kwargs):  # noqa: E501
        """UpdateDataTypeMapping  # noqa: E501

        Updates a data type mapping.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_data_type_mapping(container_id, data_source_id, mapping_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str data_source_id: (required)
        :param str mapping_id: (required)
        :param TypeMapping body:
        :return: UpdateDataTypeMappingResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_data_type_mapping_with_http_info(container_id, data_source_id, mapping_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_data_type_mapping_with_http_info(container_id, data_source_id, mapping_id, **kwargs)  # noqa: E501
            return data

    def update_data_type_mapping_with_http_info(self, container_id, data_source_id, mapping_id, **kwargs):  # noqa: E501
        """UpdateDataTypeMapping  # noqa: E501

        Updates a data type mapping.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_data_type_mapping_with_http_info(container_id, data_source_id, mapping_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str data_source_id: (required)
        :param str mapping_id: (required)
        :param TypeMapping body:
        :return: UpdateDataTypeMappingResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'data_source_id', 'mapping_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_data_type_mapping" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `update_data_type_mapping`")  # noqa: E501
        # verify the required parameter 'data_source_id' is set
        if ('data_source_id' not in params or
                params['data_source_id'] is None):
            raise ValueError("Missing the required parameter `data_source_id` when calling `update_data_type_mapping`")  # noqa: E501
        # verify the required parameter 'mapping_id' is set
        if ('mapping_id' not in params or
                params['mapping_id'] is None):
            raise ValueError("Missing the required parameter `mapping_id` when calling `update_data_type_mapping`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'data_source_id' in params:
            path_params['data_source_id'] = params['data_source_id']  # noqa: E501
        if 'mapping_id' in params:
            path_params['mapping_id'] = params['mapping_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['httpBearer']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/import/datasources/{data_source_id}/mappings/{mapping_id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UpdateDataTypeMappingResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_transformation(self, body, container_id, data_source_id, mapping_id, transformation_id, **kwargs):  # noqa: E501
        """UpdateTransformation  # noqa: E501

        Update a transformation.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_transformation(body, container_id, data_source_id, mapping_id, transformation_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateTypeMappingTransformationsRequest body: (required)
        :param str container_id: (required)
        :param str data_source_id: (required)
        :param str mapping_id: (required)
        :param str transformation_id: (required)
        :return: UpdateTransformationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_transformation_with_http_info(body, container_id, data_source_id, mapping_id, transformation_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_transformation_with_http_info(body, container_id, data_source_id, mapping_id, transformation_id, **kwargs)  # noqa: E501
            return data

    def update_transformation_with_http_info(self, body, container_id, data_source_id, mapping_id, transformation_id, **kwargs):  # noqa: E501
        """UpdateTransformation  # noqa: E501

        Update a transformation.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_transformation_with_http_info(body, container_id, data_source_id, mapping_id, transformation_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateTypeMappingTransformationsRequest body: (required)
        :param str container_id: (required)
        :param str data_source_id: (required)
        :param str mapping_id: (required)
        :param str transformation_id: (required)
        :return: UpdateTransformationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'container_id', 'data_source_id', 'mapping_id', 'transformation_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_transformation" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_transformation`")  # noqa: E501
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `update_transformation`")  # noqa: E501
        # verify the required parameter 'data_source_id' is set
        if ('data_source_id' not in params or
                params['data_source_id'] is None):
            raise ValueError("Missing the required parameter `data_source_id` when calling `update_transformation`")  # noqa: E501
        # verify the required parameter 'mapping_id' is set
        if ('mapping_id' not in params or
                params['mapping_id'] is None):
            raise ValueError("Missing the required parameter `mapping_id` when calling `update_transformation`")  # noqa: E501
        # verify the required parameter 'transformation_id' is set
        if ('transformation_id' not in params or
                params['transformation_id'] is None):
            raise ValueError("Missing the required parameter `transformation_id` when calling `update_transformation`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'data_source_id' in params:
            path_params['data_source_id'] = params['data_source_id']  # noqa: E501
        if 'mapping_id' in params:
            path_params['mapping_id'] = params['mapping_id']  # noqa: E501
        if 'transformation_id' in params:
            path_params['transformation_id'] = params['transformation_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['httpBearer']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/import/datasources/{data_source_id}/mappings/{mapping_id}/transformations/{transformation_id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UpdateTransformationResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Deep Lynx

    The construction of megaprojects has consistently demonstrated challenges for project managers in regard to meeting cost, schedule, and performance requirements. Megaproject construction challenges are common place within megaprojects with many active projects in the United States failing to meet cost and schedule efforts by significant margins. Currently, engineering teams operate in siloed tools and disparate teams where connections across design, procurement, and construction systems are translated manually or over brittle point-to-point integrations. The manual nature of data exchange increases the risk of silent errors in the reactor design, with each silent error cascading across the design. These cascading errors lead to uncontrollable risk during construction, resulting in significant delays and cost overruns. Deep Lynx allows for an integrated platform during design and operations of mega projects.  The Deep Lynx Core API delivers a few main features.  1. Provides a set of methods and endpoints for manipulating data in an object oriented database. This allows us to store complex datatypes as records and then to compile them into actual, modifiable objects at run-time. Users can store taxonomies or ontologies in a readable format.  2. Provides methods for storing and retrieving data in a graph database. This data is structured and validated against the aformentioned object oriented database before storage.  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Node(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'properties': 'object',
        'id': 'str',
        'container_id': 'str',
        'metatype': 'NodeMetatypeBody',
        'metatype_name': 'str',
        'graph_id': 'str',
        'archived': 'bool',
        'created_at': 'str',
        'modified_at': 'str',
        'original_data_id': 'str',
        'data_source_id': 'str',
        'deleted_at': 'str',
        'data_staging_id': 'float',
        'import_data_id': 'str',
        'type_mapping_transformation_id': 'str',
        'composite_original_id': 'str',
        'created_by': 'str',
        'modified_by': 'str'
    }

    attribute_map = {
        'properties': 'properties',
        'id': 'id',
        'container_id': 'container_id',
        'metatype': 'metatype',
        'metatype_name': 'metatype_name',
        'graph_id': 'graph_id',
        'archived': 'archived',
        'created_at': 'created_at',
        'modified_at': 'modified_at',
        'original_data_id': 'original_data_id',
        'data_source_id': 'data_source_id',
        'deleted_at': 'deleted_at',
        'data_staging_id': 'data_staging_id',
        'import_data_id': 'import_data_id',
        'type_mapping_transformation_id': 'type_mapping_transformation_id',
        'composite_original_id': 'composite_original_id',
        'created_by': 'created_by',
        'modified_by': 'modified_by'
    }

    def __init__(self, properties=None, id=None, container_id=None, metatype=None, metatype_name=None, graph_id=None, archived=None, created_at=None, modified_at=None, original_data_id=None, data_source_id=None, deleted_at=None, data_staging_id=None, import_data_id=None, type_mapping_transformation_id=None, composite_original_id=None, created_by=None, modified_by=None):  # noqa: E501
        """Node - a model defined in Swagger"""  # noqa: E501
        self._properties = None
        self._id = None
        self._container_id = None
        self._metatype = None
        self._metatype_name = None
        self._graph_id = None
        self._archived = None
        self._created_at = None
        self._modified_at = None
        self._original_data_id = None
        self._data_source_id = None
        self._deleted_at = None
        self._data_staging_id = None
        self._import_data_id = None
        self._type_mapping_transformation_id = None
        self._composite_original_id = None
        self._created_by = None
        self._modified_by = None
        self.discriminator = None
        self.properties = properties
        self.id = id
        self.container_id = container_id
        if metatype is not None:
            self.metatype = metatype
        self.metatype_name = metatype_name
        self.graph_id = graph_id
        self.archived = archived
        self.created_at = created_at
        if modified_at is not None:
            self.modified_at = modified_at
        self.original_data_id = original_data_id
        self.data_source_id = data_source_id
        if deleted_at is not None:
            self.deleted_at = deleted_at
        self.data_staging_id = data_staging_id
        self.import_data_id = import_data_id
        self.type_mapping_transformation_id = type_mapping_transformation_id
        self.composite_original_id = composite_original_id
        self.created_by = created_by
        self.modified_by = modified_by

    @property
    def properties(self):
        """Gets the properties of this Node.  # noqa: E501


        :return: The properties of this Node.  # noqa: E501
        :rtype: object
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this Node.


        :param properties: The properties of this Node.  # noqa: E501
        :type: object
        """
        if properties is None:
            raise ValueError("Invalid value for `properties`, must not be `None`")  # noqa: E501

        self._properties = properties

    @property
    def id(self):
        """Gets the id of this Node.  # noqa: E501


        :return: The id of this Node.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Node.


        :param id: The id of this Node.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def container_id(self):
        """Gets the container_id of this Node.  # noqa: E501


        :return: The container_id of this Node.  # noqa: E501
        :rtype: str
        """
        return self._container_id

    @container_id.setter
    def container_id(self, container_id):
        """Sets the container_id of this Node.


        :param container_id: The container_id of this Node.  # noqa: E501
        :type: str
        """
        if container_id is None:
            raise ValueError("Invalid value for `container_id`, must not be `None`")  # noqa: E501

        self._container_id = container_id

    @property
    def metatype(self):
        """Gets the metatype of this Node.  # noqa: E501


        :return: The metatype of this Node.  # noqa: E501
        :rtype: NodeMetatypeBody
        """
        return self._metatype

    @metatype.setter
    def metatype(self, metatype):
        """Sets the metatype of this Node.


        :param metatype: The metatype of this Node.  # noqa: E501
        :type: NodeMetatypeBody
        """

        self._metatype = metatype

    @property
    def metatype_name(self):
        """Gets the metatype_name of this Node.  # noqa: E501


        :return: The metatype_name of this Node.  # noqa: E501
        :rtype: str
        """
        return self._metatype_name

    @metatype_name.setter
    def metatype_name(self, metatype_name):
        """Sets the metatype_name of this Node.


        :param metatype_name: The metatype_name of this Node.  # noqa: E501
        :type: str
        """
        if metatype_name is None:
            raise ValueError("Invalid value for `metatype_name`, must not be `None`")  # noqa: E501

        self._metatype_name = metatype_name

    @property
    def graph_id(self):
        """Gets the graph_id of this Node.  # noqa: E501


        :return: The graph_id of this Node.  # noqa: E501
        :rtype: str
        """
        return self._graph_id

    @graph_id.setter
    def graph_id(self, graph_id):
        """Sets the graph_id of this Node.


        :param graph_id: The graph_id of this Node.  # noqa: E501
        :type: str
        """
        if graph_id is None:
            raise ValueError("Invalid value for `graph_id`, must not be `None`")  # noqa: E501

        self._graph_id = graph_id

    @property
    def archived(self):
        """Gets the archived of this Node.  # noqa: E501


        :return: The archived of this Node.  # noqa: E501
        :rtype: bool
        """
        return self._archived

    @archived.setter
    def archived(self, archived):
        """Sets the archived of this Node.


        :param archived: The archived of this Node.  # noqa: E501
        :type: bool
        """
        if archived is None:
            raise ValueError("Invalid value for `archived`, must not be `None`")  # noqa: E501

        self._archived = archived

    @property
    def created_at(self):
        """Gets the created_at of this Node.  # noqa: E501


        :return: The created_at of this Node.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Node.


        :param created_at: The created_at of this Node.  # noqa: E501
        :type: str
        """
        if created_at is None:
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def modified_at(self):
        """Gets the modified_at of this Node.  # noqa: E501


        :return: The modified_at of this Node.  # noqa: E501
        :rtype: str
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this Node.


        :param modified_at: The modified_at of this Node.  # noqa: E501
        :type: str
        """

        self._modified_at = modified_at

    @property
    def original_data_id(self):
        """Gets the original_data_id of this Node.  # noqa: E501


        :return: The original_data_id of this Node.  # noqa: E501
        :rtype: str
        """
        return self._original_data_id

    @original_data_id.setter
    def original_data_id(self, original_data_id):
        """Sets the original_data_id of this Node.


        :param original_data_id: The original_data_id of this Node.  # noqa: E501
        :type: str
        """
        if original_data_id is None:
            raise ValueError("Invalid value for `original_data_id`, must not be `None`")  # noqa: E501

        self._original_data_id = original_data_id

    @property
    def data_source_id(self):
        """Gets the data_source_id of this Node.  # noqa: E501


        :return: The data_source_id of this Node.  # noqa: E501
        :rtype: str
        """
        return self._data_source_id

    @data_source_id.setter
    def data_source_id(self, data_source_id):
        """Sets the data_source_id of this Node.


        :param data_source_id: The data_source_id of this Node.  # noqa: E501
        :type: str
        """
        if data_source_id is None:
            raise ValueError("Invalid value for `data_source_id`, must not be `None`")  # noqa: E501

        self._data_source_id = data_source_id

    @property
    def deleted_at(self):
        """Gets the deleted_at of this Node.  # noqa: E501


        :return: The deleted_at of this Node.  # noqa: E501
        :rtype: str
        """
        return self._deleted_at

    @deleted_at.setter
    def deleted_at(self, deleted_at):
        """Sets the deleted_at of this Node.


        :param deleted_at: The deleted_at of this Node.  # noqa: E501
        :type: str
        """

        self._deleted_at = deleted_at

    @property
    def data_staging_id(self):
        """Gets the data_staging_id of this Node.  # noqa: E501


        :return: The data_staging_id of this Node.  # noqa: E501
        :rtype: float
        """
        return self._data_staging_id

    @data_staging_id.setter
    def data_staging_id(self, data_staging_id):
        """Sets the data_staging_id of this Node.


        :param data_staging_id: The data_staging_id of this Node.  # noqa: E501
        :type: float
        """
        if data_staging_id is None:
            raise ValueError("Invalid value for `data_staging_id`, must not be `None`")  # noqa: E501

        self._data_staging_id = data_staging_id

    @property
    def import_data_id(self):
        """Gets the import_data_id of this Node.  # noqa: E501


        :return: The import_data_id of this Node.  # noqa: E501
        :rtype: str
        """
        return self._import_data_id

    @import_data_id.setter
    def import_data_id(self, import_data_id):
        """Sets the import_data_id of this Node.


        :param import_data_id: The import_data_id of this Node.  # noqa: E501
        :type: str
        """
        if import_data_id is None:
            raise ValueError("Invalid value for `import_data_id`, must not be `None`")  # noqa: E501

        self._import_data_id = import_data_id

    @property
    def type_mapping_transformation_id(self):
        """Gets the type_mapping_transformation_id of this Node.  # noqa: E501


        :return: The type_mapping_transformation_id of this Node.  # noqa: E501
        :rtype: str
        """
        return self._type_mapping_transformation_id

    @type_mapping_transformation_id.setter
    def type_mapping_transformation_id(self, type_mapping_transformation_id):
        """Sets the type_mapping_transformation_id of this Node.


        :param type_mapping_transformation_id: The type_mapping_transformation_id of this Node.  # noqa: E501
        :type: str
        """
        if type_mapping_transformation_id is None:
            raise ValueError("Invalid value for `type_mapping_transformation_id`, must not be `None`")  # noqa: E501

        self._type_mapping_transformation_id = type_mapping_transformation_id

    @property
    def composite_original_id(self):
        """Gets the composite_original_id of this Node.  # noqa: E501


        :return: The composite_original_id of this Node.  # noqa: E501
        :rtype: str
        """
        return self._composite_original_id

    @composite_original_id.setter
    def composite_original_id(self, composite_original_id):
        """Sets the composite_original_id of this Node.


        :param composite_original_id: The composite_original_id of this Node.  # noqa: E501
        :type: str
        """
        if composite_original_id is None:
            raise ValueError("Invalid value for `composite_original_id`, must not be `None`")  # noqa: E501

        self._composite_original_id = composite_original_id

    @property
    def created_by(self):
        """Gets the created_by of this Node.  # noqa: E501


        :return: The created_by of this Node.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this Node.


        :param created_by: The created_by of this Node.  # noqa: E501
        :type: str
        """
        if created_by is None:
            raise ValueError("Invalid value for `created_by`, must not be `None`")  # noqa: E501

        self._created_by = created_by

    @property
    def modified_by(self):
        """Gets the modified_by of this Node.  # noqa: E501


        :return: The modified_by of this Node.  # noqa: E501
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """Sets the modified_by of this Node.


        :param modified_by: The modified_by of this Node.  # noqa: E501
        :type: str
        """
        if modified_by is None:
            raise ValueError("Invalid value for `modified_by`, must not be `None`")  # noqa: E501

        self._modified_by = modified_by

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Node, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Node):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
